@@ -1,6 +1,6 @@
 /*
  * Photos - access, organize and share your photos on GNOME
- * Copyright © 2012 – 2016 Red Hat, Inc.
+ * Copyright © 2012 – 2017 Red Hat, Inc.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -50,7 +50,7 @@ gint
 main (gint argc, gchar *argv[])
 {
   EggCounterArena *counter_arena;
-  GtkApplication *app;
+  GApplication *app;
   PhotosRemoteDisplayManager *remote_display_mngr;
   gint exit_status;
 
@@ -66,10 +66,10 @@ main (gint argc, gchar *argv[])
 
   app = photos_application_new ();
   if (g_getenv ("GNOME_PHOTOS_PERSIST") != NULL)
-    g_application_hold (G_APPLICATION (app));
+    g_application_hold (app);
 
   remote_display_mngr = photos_remote_display_manager_dup_singleton ();
-  exit_status = g_application_run (G_APPLICATION (app), argc, argv);
+  exit_status = g_application_run (app, argc, argv);
   g_object_unref (remote_display_mngr);
   g_object_unref (app);
 
