@@ -1,6 +1,6 @@
 /*
  * Photos - access, organize and share your photos on GNOME
- * Copyright © 2013 – 2016 Red Hat, Inc.
+ * Copyright © 2013 – 2017 Red Hat, Inc.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -44,7 +44,6 @@
 struct _PhotosPreviewView
 {
   GtkBin parent_instance;
-  GAction *draw;
   GCancellable *cancellable;
   GeglNode *node;
   GtkWidget *overlay;
@@ -271,7 +270,6 @@ photos_preview_view_get_view_from_view_container (GtkWidget *view_container)
 static void
 photos_preview_view_process (GObject *source_object, GAsyncResult *res, gpointer user_data)
 {
-  PhotosPreviewView *self;
   GError *error = NULL;
   PhotosBaseItem *item = PHOTOS_BASE_ITEM (source_object);
 
@@ -289,10 +287,43 @@ photos_preview_view_process (GObject *source_object, GAsyncResult *res, gpointer
           g_error_free (error);
         }
     }
+}
 
-  self = PHOTOS_PREVIEW_VIEW (user_data);
 
-  g_action_activate (self->draw, NULL);
+static void
+photos_preview_view_blacks_exposure (PhotosPreviewView *self, GVariant *parameter)
+{
+  GVariantIter iter;
+  PhotosBaseItem *item;
+  const gchar *key;
+  gdouble blacks = -G_MAXDOUBLE;
+  gdouble exposure = -G_MAXDOUBLE;
+  gdouble value;
+
+  item = PHOTOS_BASE_ITEM (photos_base_manager_get_active_object (self->item_mngr));
+  if (item == NULL)
+    return;
+
+  g_variant_iter_init (&iter, parameter);
+  while (g_variant_iter_next (&iter, "{&sd}", &key, &value))
+    {
+      if (g_strcmp0 (key, "blacks") == 0)
+        blacks = value;
+      else if (g_strcmp0 (key, "exposure") == 0)
+        exposure = value;
+    }
+
+  g_return_if_fail (blacks > -G_MAXDOUBLE);
+  g_return_if_fail (exposure > -G_MAXDOUBLE);
+
+  photos_base_item_operation_add_async (item,
+                                        self->cancellable,
+                                        photos_preview_view_process,
+                                        self,
+                                        "gegl:exposure",
+                                        "black-level", blacks,
+                                        "exposure", exposure,
+                                        NULL);
 }
 
 
@@ -401,18 +432,6 @@ photos_preview_view_denoise (PhotosPreviewView *self, GVariant *parameter)
 }
 
 
-static void
-photos_preview_view_draw (PhotosPreviewView *self)
-{
-  GtkWidget *view;
-  GtkWidget *view_container;
-
-  view_container = gtk_stack_get_visible_child (GTK_STACK (self->stack));
-  view = photos_preview_view_get_view_from_view_container (view_container);
-  gtk_widget_queue_draw (view);
-}
-
-
 static void
 photos_preview_view_insta (PhotosPreviewView *self, GVariant *parameter)
 {
@@ -485,8 +504,6 @@ photos_preview_view_tool_activated (PhotosTool *tool, gpointer user_data)
 
   self->current_tool = tool;
   g_object_add_weak_pointer (G_OBJECT (self->current_tool), (gpointer *) &self->current_tool);
-
-  g_action_activate (self->draw, NULL);
 }
 
 
@@ -507,7 +524,6 @@ photos_preview_view_tool_changed (PhotosPreviewView *self, PhotosTool *tool)
   if (tool == NULL)
     {
       self->current_tool = NULL;
-      g_action_activate (self->draw, NULL);
     }
   else
     {
@@ -565,6 +581,11 @@ photos_preview_view_edit_done (PhotosPreviewView *self)
   item = PHOTOS_BASE_ITEM (photos_base_manager_get_active_object (self->item_mngr));
   g_return_if_fail (item != NULL);
 
+  /* We need to withdraw the palette's row before saving the pipeline so
+   * that we don't miss the application of the current tool. Some
+   * tools (eg., crop) use their deactivated virtual method to apply
+   * themselves, and that happens when the row gets hidden.
+   */
   photos_edit_palette_hide_details (PHOTOS_EDIT_PALETTE (self->palette));
 
   app = g_application_get_default ();
@@ -731,6 +752,13 @@ photos_preview_view_init (PhotosPreviewView *self)
   gtk_container_add (GTK_CONTAINER (sw), self->palette);
   g_signal_connect_swapped (self->palette, "tool-changed", G_CALLBACK (photos_preview_view_tool_changed), self);
 
+  action = g_action_map_lookup_action (G_ACTION_MAP (app), "blacks-exposure-current");
+  g_signal_connect_object (action,
+                           "activate",
+                           G_CALLBACK (photos_preview_view_blacks_exposure),
+                           self,
+                           G_CONNECT_SWAPPED);
+
   action = g_action_map_lookup_action (G_ACTION_MAP (app), "brightness-contrast-current");
   g_signal_connect_object (action,
                            "activate",
@@ -744,9 +772,6 @@ photos_preview_view_init (PhotosPreviewView *self)
   action = g_action_map_lookup_action (G_ACTION_MAP (app), "denoise-current");
   g_signal_connect_object (action, "activate", G_CALLBACK (photos_preview_view_denoise), self, G_CONNECT_SWAPPED);
 
-  self->draw = g_action_map_lookup_action (G_ACTION_MAP (app), "draw-current");
-  g_signal_connect_object (self->draw, "activate", G_CALLBACK (photos_preview_view_draw), self, G_CONNECT_SWAPPED);
-
   action = g_action_map_lookup_action (G_ACTION_MAP (app), "edit-done");
   g_signal_connect_object (action, "activate", G_CALLBACK (photos_preview_view_edit_done), self, G_CONNECT_SWAPPED);
 
