@@ -22,7 +22,6 @@
  *   + Documents
  *   + Eye of GNOME
  *   + Shotwell
- *   + Totem
  */
 
 #ifndef PHOTOS_UTILS_H
@@ -53,8 +52,6 @@ G_BEGIN_DECLS
   "http://www.semanticdesktop.org/ontologies/2007/03/22/nfo#image-category-screenshot"
 #define PHOTOS_EXPORT_SUBPATH "Exports"
 
-void             photos_utils_border_pixbuf               (GdkPixbuf *pixbuf);
-
 GdkPixbuf       *photos_utils_center_pixbuf               (GdkPixbuf *pixbuf, gint size);
 
 gchar           *photos_utils_convert_path_to_uri         (const gchar *path);
@@ -150,6 +147,8 @@ gchar           *photos_utils_get_thumbnail_path_for_uri  (const gchar *uri);
 
 GList           *photos_utils_get_urns_from_items         (GList *items);
 
+const gchar     *photos_utils_get_version                 (void);
+
 GIcon           *photos_utils_icon_from_rdf_type          (const gchar *type);
 
 void             photos_utils_list_box_header_func        (GtkListBoxRow *row,
